@@ -538,6 +538,7 @@ contentdir_search(ActionEvent *event)
     search_criteria = upnp_get_string(event, "SearchCriteria");
     sort_criteria = upnp_get_string(event, "SortCriteria");
     filter = upnp_get_string(event, "Filter");
+    strreplace(filter, ' ', ','); /* XXX: This is a hack. Better remove all spaces. */
     index = upnp_get_ui4(event, "StartingIndex");
     count = upnp_get_ui4(event, "RequestedCount");
     if (!event->status)
@@ -620,6 +621,7 @@ contentdir_browse(ActionEvent *event)
     /* XXX: is this OK? maybe we should use a more appropriate error response if not int32. */
     id = upnp_get_i4(event, "ObjectID"); 
     filter = upnp_get_string(event, "Filter");
+    strreplace(filter, ' ', ','); /* XXX: This is a hack. Better remove all spaces. */
     flag = upnp_get_string(event, "BrowseFlag");
     sort_criteria = upnp_get_string(event, "SortCriteria");
     if (!event->status)
@@ -726,7 +728,7 @@ init_contentdir(void)
 void
 finish_contentdir(void)
 {
-    free(find_variable("SystemUpdateID"));
+    free(find_variable("SystemUpdateID")->value);
 }
 
 /* XXX: In the future, ServiceVariable should allow different
