@@ -188,9 +188,7 @@ char *get_ip_by_spec(char *spec);
 
 /* metadata.c */
 extern char *file_types;
-#ifdef HAVE_ID3LIB
-extern bool id3_enabled;
-#endif
+extern bool tags_enabled;
 void init_metadata(void);
 bool scan_entries(char **pathv, int pathc);
 void clear_entries(void);
@@ -251,6 +249,7 @@ void bump_update_id(void);
 void free_search_criteria(SearchCriteria *criteria);
 void free_search_expr(SearchExpr *expr);
 void init_contentdir(void);
+void finish_contentdir(void);
 
 /* connectmgr.c */
 #define CONNECTMGR_SERVICE_ID "urn:upnp-org:serviceId:ConnectionManager"
