@@ -31,6 +31,7 @@
 #define N_(s) gettext_noop(s)
 #include "strftime.h"		/* Gnulib */
 #include "progname.h"		/* Gnulib */
+#include "quote.h"		/* Gnulib */
 #include "gmediaserver.h"
 
 #define MAX_TIMESTAMP_LENGTH 1024
@@ -73,7 +74,7 @@ init_logging(const char *logfilename, const char *ts_format)
     if (logfilename != NULL) {
         logfh = fopen(logfilename, "a");
         if (logfh == NULL)
-            die(_("cannot open log file `%s' for appending\n"), logfilename);
+            die(_("cannot open log file %s for appending\n"), quote(logfilename));
         setlinebuf(logfh);
     }
     say(1, _("%s process id %d starting\n"), PACKAGE, getpid());
