@@ -51,7 +51,7 @@
 #include "gmediaserver.h"
 
 enum {
-    OPT_DISABLE_ID3,
+    OPT_DISABLE_TAGS,
     OPT_IN_CHARSET,
     OPT_DEVICE_CHARSET,
     OPT_FRIENDLY_NAME,
@@ -68,9 +68,7 @@ enum {
 
 static const char *short_options = "bv::i:o:p:";
 static struct option long_options[] = {
-#ifdef HAVE_ID3LIB
-    { "disable-id3", no_argument, NULL, OPT_DISABLE_ID3 },
-#endif
+    { "disable-tags", no_argument, NULL, OPT_DISABLE_TAGS },
     { "in-charset", required_argument, NULL, OPT_IN_CHARSET },
     { "device-charset", required_argument, NULL, OPT_DEVICE_CHARSET },
     { "friendly-name", required_argument, NULL, OPT_FRIENDLY_NAME },
@@ -169,11 +167,9 @@ main(int argc, char **argv)
         case 'o':
             logfilename = optarg;
             break;
-#ifdef HAVE_ID3LIB
-	case OPT_DISABLE_ID3:
-	    id3_enabled = false;
+	case OPT_DISABLE_TAGS:
+	    tags_enabled = false;
 	    break;
-#endif
         case OPT_IN_CHARSET:
             in_charset = optarg;
             break;
@@ -247,9 +243,7 @@ main(int argc, char **argv)
             printf(_("Usage: %s [OPTIONS]... DIRECTORIES...\n"), argv[0]);
             printf(_("Run the UPnP media server.\n\n"));
 	    printf(_("      --friendly-name=NAME   set display name for media server\n"));
-#ifdef HAVE_ID3LIB
-	    printf(_("      --disable-id3          do not scan files for ID3 information\n"));
-#endif
+	    printf(_("      --disable-tags          do not scan files for tags\n"));
 	    printf(_("  -v, --verbose[=LEVEL]      set verbosity level (0-4)\n"));
             printf(_("      --pid-file=FILE        write pid to FILE when up and running\n"));
             printf(_("  -i, --interface=NAME       listen on a specific interface\n"));
