@@ -18,13 +18,16 @@
  *
  */
 
-#include <config.h>
 #include <config.h>
 #ifdef HAVE_ID3LIB
 #include <id3.h>                /* id3lib */
 #undef false /* id3lib bug - it shouldn't mess with false and true! */
 #undef true
 #endif
+#ifdef HAVE_TAGLIB
+#include <tag_c.h>
+#undef BOOL /* conflicts with libupnp */
+#endif
 #include <stdbool.h>            /* Gnulib, C99 */
 #include <stdint.h>		/* Gnulib, C99 */
 #include <dirent.h>		/* POSIX */
@@ -115,8 +118,8 @@ static uint32_t entries_size = 0;
 static Entry **entries;
 char *file_types = DEFAULT_FILE_TYPES;
 static ithread_mutex_t metadata_mutex;
+bool tags_enabled = true;
 #ifdef HAVE_ID3LIB
-bool id3_enabled = true;
 static ID3Tag *id3;
 #endif
 
@@ -201,7 +204,7 @@ attempt_read_at(int fd, size_t size, off_t pos, uint8_t *buf, const char *fullpa
     }
 
     count = full_read(fd, buf, size);
-    if (count < 4) {
+    if (count < size) {
 	if (errno != 0)
 	    warn(_("%s: cannot read: %s\n"), quotearg(fullpath), errstr);
 	close(fd); /* Ignore errors since we opened for reading */
@@ -216,6 +219,7 @@ check_file_content_type(const char *fullpath)
     int fd;
     uint8_t buf[11];
 
+    /* XXX: Use stdio instead of fd syscalls */
     fd = open(fullpath, O_RDONLY);
     if (fd < 0) {
 	warn(_("%s: cannot open for reading: %s\n"), quotearg(fullpath), errstr);
@@ -251,12 +255,12 @@ check_file_content_type(const char *fullpath)
     }
 
     /* ISO Media, MPEG v4 system, iTunes AAC-LC */
-    if (!attempt_read_at(fd, 4, 4, buf, fullpath))
+    if (!attempt_read_at(fd, 4, 4, buf+4, fullpath))
 	return FILE_UNKNOWN;
-    if (buf[0] == 'f' && buf[1] == 't' && buf[2] == 'y' && buf[3] == 'p') {
-	if (!attempt_read_at(fd, 4, 8, buf, fullpath))
+    if (buf[4] == 'f' && buf[5] == 't' && buf[6] == 'y' && buf[7] == 'p') {
+	if (!attempt_read_at(fd, 4, 8, buf+8, fullpath))
 	    return FILE_UNKNOWN;
-	if (buf[0] == 'M' && buf[1] == '4' && buf[2] == 'A') {
+	if (buf[8] == 'M' && buf[9] == '4' && buf[10] == 'A') {
 	    close(fd); /* Ignore errors since we opened for reading */
 	    return FILE_M4A;
 	}
@@ -268,7 +272,7 @@ check_file_content_type(const char *fullpath)
         return FILE_EXTM3U;
     }
     /* Playlist (PLS) */
-    if (!attempt_read_at(fd, 11, 0, buf, fullpath))
+    if (!attempt_read_at(fd, 4, 8, buf+8, fullpath))
 	return FILE_UNKNOWN;
     if (memcmp(buf, "[playlist]", 10) == 0 && (buf[10] == '\r' || buf[10] == '\n')) {
 	close(fd); /* Ignore errors since we opened for reading */
@@ -550,8 +554,8 @@ scan_entry(const char *fullpath, const char *name, int32_t parent)
         detail->data.file.filename = xstrdup(fullpath);
 	detail->data.file.mime_type = file_type_mime_types[type];
 
+	if (tags_enabled && (type == FILE_MP3 || type == FILE_MP3_ID3)) {
 #ifdef HAVE_ID3LIB
-	if (id3_enabled && (type == FILE_MP3 || type == FILE_MP3_ID3)) {
 	    /*char *title;*/
 	
 	    ID3Tag_Clear(id3);
@@ -571,8 +575,29 @@ scan_entry(const char *fullpath, const char *name, int32_t parent)
                 detail->data.tag.artist = get_id3_string(id3, ID3FID_LEADARTIST);
                 detail->data.tag.genre = get_id3_string(id3, ID3FID_CONTENTTYPE);
 	    }
-        }
 #endif
+#ifdef HAVE_TAGLIB
+            {
+                TagLib_File *tl_file;
+
+		/* FIXME: change TagLib_File_MPEG when OGG support added */
+                tl_file = taglib_file_new_type(fullpath, TagLib_File_MPEG); 
+                if (tl_file != NULL) {
+                    TagLib_Tag *tl_tag;
+
+                    tl_tag = taglib_file_tag(tl_file);
+                    detail = add_entry_detail(entry, DETAIL_TAG);
+                    detail->data.tag.title = xstrdup(taglib_tag_title(tl_tag));
+
+                    detail->data.tag.album = xstrdup(taglib_tag_album(tl_tag));
+                    detail->data.tag.artist = xstrdup(taglib_tag_artist(tl_tag));
+                    detail->data.tag.genre = xstrdup(taglib_tag_genre(tl_tag));
+                    taglib_tag_free_strings();
+                    taglib_file_free(tl_file);
+                }
+            }
+#endif
+        }
 
         return entry;
     }
@@ -590,7 +615,7 @@ init_metadata(void)
     entries = xmalloc(sizeof(Entry *) * entries_size);
 
 #ifdef HAVE_ID3LIB
-    if (id3_enabled)
+    if (tags_enabled)
 	id3 = ID3Tag_New();
 #endif
 }
@@ -672,7 +697,7 @@ finish_metadata(void)
 {
     clear_entries();
 #ifdef HAVE_ID3LIB
-    if (id3_enabled)
+    if (tags_enabled)
 	ID3Tag_Delete(id3);
 #endif
     free(entries);
