@@ -144,3 +144,13 @@ concat_filenames(const char *p1, const char *p2)
     memcpy(out+l1+1, p2, l2+1);
     return out;
 }
+
+/* Replace all occurences of in with out in str. */
+void
+strreplace(char *str, char in, char out)
+{
+    for (; *str != '\0'; str++) {
+	if (*str == in)
+	    *str = out;
+    }
+}
